<TS language="be_BY" version="2.0">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>Стварыць новы адрас</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>Новы</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Капіяваць пазначаны адрас у сістэмны буфер абмену</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>Капіяваць</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>Выдаліць абраны адрас са спісу</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>Выдаліць</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>Капіяваць Метку</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>Рэдагаваць</translation>
    </message>
    </context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>Метка</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Адрас</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>непазначаны</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>Дыялог сакрэтнай фразы</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>Увядзіце кодавую фразу</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Новая кодавая фраза</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Паўтарыце новую кодавую фразу</translation>
    </message>
    <message>
        <source>Enter the new passphrase to the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
        <translation>Увядзіце новы пароль для гаманца.&lt;br/&gt;Парольная фраза павинна складацца&lt;b&gt; не меньш чым з дзесяці сімвалаў&lt;/b&gt;, ці &lt;b&gt;больш чым з васьмі слоў&lt;/b&gt;.</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>Зашыфраваць гаманец.</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>Гэтая аперацыя патрабуе кодавую фразу, каб рзблакаваць гаманец.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Разблакаваць гаманец</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>Змяніць пароль</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>Пацвердзіце шыфраванне гаманца</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation>Ці ўпэўненыя вы, што жадаеце зашыфраваць свой гаманец?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>Гаманец зашыфраваны</translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation>ВАЖНА: Усе папярэднія копіі гаманца варта замяніць новым зашыфраваным файлам. У мэтах бяспекі папярэднія копіі незашыфраванага файла-гаманца стануць неўжывальнымі, калі вы станеце карыстацца новым зашыфраваным гаманцом.</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation>Шыфраванне гаманца няўдалае</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation>Шыфраванне гаманца не адбылося з-за ўнутранай памылкі. Гаманец незашыфраваны.</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation>Уведдзеныя паролі не супадаюць</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation>Разблакаванне гаманца няўдалае</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation>Уведзены пароль  для расшыфравання гаманца памылковы</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation>Парольная фраза гаманца паспяхова зменена.</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation>Увага: Caps Lock уключаны!</translation>
    </message>
</context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Wallet</source>
        <translation>Гаманец</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>Агляд</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>Паказвае агульныя звесткі аб гаманцы</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>Даслаць</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>Атрымаць</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>Праглядзець гісторыю транзакцый</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>Выйсці</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>Выйсці з праграмы</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>Опцыі...</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>&amp;Паказаць / Схаваць</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>Зашыфраваць Гаманец...</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>Змяніць пароль шыфравання гаманца</translation>
    </message>
    <message>
        <source>Sign &amp;message...</source>
        <translation>Падпісаць паведамленне...</translation>
    </message>
    <message>
        <source>&amp;Verify message...</source>
        <translation>Праверыць паведамленне...</translation>
    </message>
    <message>
        <source>&amp;Debug window</source>
        <translation>Вакно адладкі</translation>
    </message>
    <message>
        <source>Open debugging and diagnostic console</source>
        <translation>Адкрыць кансоль дыягностыкі і адладкі</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>Ф&amp;айл</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>Наладкі</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>Дапамога</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to the Gridcoin network</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n second(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>Сінхранізавана</translation>
    </message>
    <message>
        <source>Catching up...</source>
        <translation>Наганяем...</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>Дасланыя транзакцыі</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>Прынятыя транзакцыі</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation>Гаманец &lt;b&gt;зашыфраваны&lt;/b&gt; і зараз &lt;b&gt;заблакаваны&lt;/b&gt;</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Quantity:</source>
        <translation>Колькасць:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>Байтаў:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Колькасць:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Камісія:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Пасля камісіі:</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Колькасць</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Дата</translation>
    </message>
    <message>
        <source>Confirmations</source>
        <translation>Пацверджанняў</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Пацверджана</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Капіяваць адрас</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Капіяваць пазнаку</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Капіяваць колькасць</translation>
    </message>
    <message>
        <source>Copy transaction ID</source>
        <translation>Капіяваць ID транзакцыі</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>Капіяваць колькасць</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>Капіяваць камісію</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation>Капіяваць з выняткам камісіі</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>Капіяваць байты</translation>
    </message>
    <message>
        <source>yes</source>
        <translation>так</translation>
    </message>
    <message>
        <source>no</source>
        <translation>не</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>непазначаны</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>Рэдагаваць Адрас</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation>Метка</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>Адрас</translation>
    </message>
    <message>
        <source>New receiving address</source>
        <translation>Новы адрас для атрымання</translation>
    </message>
    <message>
        <source>New sending address</source>
        <translation>Новы адрас для дасылання</translation>
    </message>
    <message>
        <source>Edit receiving address</source>
        <translation>Рэдагаваць адрас прымання</translation>
    </message>
    <message>
        <source>Edit sending address</source>
        <translation>Рэдагаваць адрас дасылання</translation>
    </message>
    <message>
        <source>The entered address "%1" is already in the address book.</source>
        <translation>Уведзены адрас "%1" ужо ў кніге адрасоў</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation>Немагчыма разблакаваць гаманец</translation>
    </message>
    <message>
        <source>New key generation failed.</source>
        <translation>Генерацыя новага ключа няўдалая</translation>
    </message>
</context>
<context>
    <name>Intro</name>
    <message numerus="yes">
        <source>%n GB of free space available</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Опцыі</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation>Форма</translation>
    </message>
    </context>
<context>
    <name>QObject</name>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>&amp;Information</source>
        <translation>Інфармацыя</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation>Даслаць Манеты</translation>
    </message>
    <message>
        <source>Insufficient funds!</source>
        <translation>Недастаткова сродкаў</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation>Колькасць:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>Байтаў:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Колькасць:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Камісія:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Пасля камісіі:</translation>
    </message>
    <message>
        <source>Send to multiple recipients at once</source>
        <translation>Даслаць адразу некалькім атрымальнікам</translation>
    </message>
    <message>
        <source>Confirm the send action</source>
        <translation>Пацвердзіць дасыланне</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>Капіяваць колькасць</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Капіяваць колькасць</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>Капіяваць камісію</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation>Капіяваць з выняткам камісіі</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>Капіяваць байты</translation>
    </message>
    <message>
        <source>Confirm send coins</source>
        <translation>Пацвердзіць дасыланне манет</translation>
    </message>
    <message>
        <source>The amount to pay must be larger than 0.</source>
        <translation>Велічыня плацяжу мае быць больш за 0.</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>непазначаны</translation>
    </message>
    </context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation>Колькасць:</translation>
    </message>
    <message>
        <source>Pay &amp;To:</source>
        <translation>Заплаціць да:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Паведамленне:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>Метка:</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Уставіць адрас з буферу абмена</translation>
    </message>
    <message>
        <source>Enter a label for this address to add it to your address book</source>
        <translation>Увядзіце пазнаку гэтаму адрасу, каб дадаць яго ў адрасную кнігу</translation>
    </message>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Уставіць адрас з буферу абмена</translation>
    </message>
    </context>
<context>
    <name>TransactionDesc</name>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>%1/unconfirmed</source>
        <translation>%1/непацверджана</translation>
    </message>
    <message>
        <source>%1 confirmations</source>
        <translation>%1 пацверджанняў</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Статус</translation>
    </message>
    <message>
        <source>, has not been successfully broadcast yet</source>
        <translation>, пакуль не было паспяхова транслявана</translation>
    </message>
    <message numerus="yes">
        <source>, broadcast through %n node(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Дата</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>невядома</translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Паведамленне</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Каментар</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Колькасць</translation>
    </message>
    </context>
<context>
    <name>TransactionDescDialog</name>
    <message>
        <source>This pane shows a detailed description of the transaction</source>
        <translation>Гэтая панэль паказвае дэтальнае апісанне транзакцыі</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>Дата</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Тып</translation>
    </message>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Confirmed (%1 confirmations)</source>
        <translation>Пацверджана (%1 пацверджанняў)</translation>
    </message>
    <message>
        <source>Generated but not accepted</source>
        <translation>Згенеравана, але не прынята</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Прынята з</translation>
    </message>
    <message>
        <source>Received from</source>
        <translation>Прынята ад</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Даслана да</translation>
    </message>
    <message>
        <source>Payment to yourself</source>
        <translation>Плацёж самому сабе</translation>
    </message>
    <message>
        <source>Transaction status. Hover over this field to show number of confirmations.</source>
        <translation>Статус транзакцыі. Навядзіце курсар на гэтае поле, каб паказаць колькасць пацверджанняў.</translation>
    </message>
    <message>
        <source>Date and time that the transaction was received.</source>
        <translation>Дата і час, калі транзакцыя была прынята.</translation>
    </message>
    <message>
        <source>Type of transaction.</source>
        <translation>Тып транзакцыі</translation>
    </message>
    <message>
        <source>Amount removed from or added to balance.</source>
        <translation>Колькасць аднятая ці даданая да балансу.</translation>
    </message>
</context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Today</source>
        <translation>Сёння</translation>
    </message>
    <message>
        <source>This week</source>
        <translation>Гэты тыдзень</translation>
    </message>
    <message>
        <source>This month</source>
        <translation>Гэты месяц</translation>
    </message>
    <message>
        <source>Last month</source>
        <translation>Мінулы месяц</translation>
    </message>
    <message>
        <source>This year</source>
        <translation>Гэты год</translation>
    </message>
    <message>
        <source>Range...</source>
        <translation>Прамежак...</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Прынята з</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Даслана да</translation>
    </message>
    <message>
        <source>To yourself</source>
        <translation>Да сябе</translation>
    </message>
    <message>
        <source>Mined</source>
        <translation>Здабыта</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Іншыя</translation>
    </message>
    <message>
        <source>Min amount</source>
        <translation>Мін. колькасць</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Капіяваць адрас</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Капіяваць пазнаку</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Капіяваць колькасць</translation>
    </message>
    <message>
        <source>Copy transaction ID</source>
        <translation>Капіяваць ID транзакцыі</translation>
    </message>
    <message>
        <source>Edit label</source>
        <translation>Рэдагаваць пазнаку</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Пацверджана</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Дата</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Тып</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Метка</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Адрас</translation>
    </message>
    <message>
        <source>Range:</source>
        <translation>Прамежак:</translation>
    </message>
    <message>
        <source>to</source>
        <translation>да</translation>
    </message>
</context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Loading addresses...</source>
        <translation>Загружаем адрасы...</translation>
    </message>
    <message>
        <source>Insufficient funds</source>
        <translation>Недастаткова сродкаў</translation>
    </message>
    <message>
        <source>Loading block index...</source>
        <translation>Загружаем індэкс блокаў...</translation>
    </message>
    <message>
        <source>Loading wallet...</source>
        <translation>Загружаем гаманец...</translation>
    </message>
    <message>
        <source>Rescanning...</source>
        <translation>Перасканаванне...</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation>Загрузка выканана</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Памылка</translation>
    </message>
</context>
</TS>